@@ -3,20 +3,19 @@ import numpy as np
 from scipy import special
 from scipy.stats import distributions
 
-
 __all__ = [
-    "_pearson_r",
-    "_pearson_r_p_value",
-    "_rmse",
-    "_mse",
-    "_mae",
-    "_median_absolute_error",
-    "_smape",
-    "_mape",
-    "_spearman_r",
-    "_spearman_r_p_value",
-    "_effective_sample_size",
-    "_r2",
+    '_pearson_r',
+    '_pearson_r_p_value',
+    '_rmse',
+    '_mse',
+    '_mae',
+    '_median_absolute_error',
+    '_smape',
+    '_mape',
+    '_spearman_r',
+    '_spearman_r_p_value',
+    '_effective_sample_size',
+    '_r2',
 ]
 
 
@@ -33,6 +32,8 @@ def _match_nans(a, b, weights):
         pairwise locations.
     """
     if np.isnan(a).any() or np.isnan(b).any():
+        # Avoids mutating original arrays and bypasses read-only issue.
+        a, b = a.copy(), b.copy()
         # Find pairwise indices in a and b that have nans.
         idx = np.logical_or(np.isnan(a), np.isnan(b))
         a[idx], b[idx] = np.nan, np.nan
